@@ -15,7 +15,7 @@ import sys, getopt
 #from oauthlib.oauth2 import BackendApplicationClient
 
 from inforion.ionapi.basic import load_config,login,header
-from inforion.ionapi.MMS import AddItmBasic,MMS021,MMS021bulk,MMS021bulk2,CRS610bulk,CRS610,CRS610bulk2,execute,executeSnd,executeAsyncSnd
+from inforion.ionapi.MMS import AddItmBasic,MMS021,MMS021bulk,MMS021bulk2,execute,executeSnd,executeAsyncSnd
 
 from inforion.helper.urlsplit import spliturl
 def main():
@@ -31,7 +31,8 @@ def main():
         print (help_string)
         sys.exit(2)
 
-
+    start = None
+    end = None
 
     for opt, arg in opts:
 
@@ -65,11 +66,18 @@ def main():
                 config = load_config(ionfile)
                 token=login(url,config)
                 
+                
+                
                 headers = header(config,token)
                 if "Bearer"  not in headers['Authorization']:
                     return "InforION Login is not working"
                 #return CRS610bulk(url,headers,inputfile,'CRS610MI',outputfile,start,end)
-                return execute(url,headers,program,method,inputfile,outputfile,start,end)  
+                if start is None or end is None:
+                    return execute(url,headers,program,method,inputfile,outputfile)  
+                    
+                else:
+                    return execute(url,headers,program,method,inputfile,outputfile,start,end)  
+                    
             if result["Call"] == "executeSnd":
     
                 config = load_config(ionfile)
